package com.gxzc.zen.msg.ws.config

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty
import org.springframework.context.annotation.Configuration
import org.springframework.messaging.simp.config.MessageBrokerRegistry
import org.springframework.web.socket.config.annotation.AbstractWebSocketMessageBrokerConfigurer
import org.springframework.web.socket.config.annotation.EnableWebSocketMessageBroker
import org.springframework.web.socket.config.annotation.StompEndpointRegistry

/**
 * WebSocket 配置
 * @author NorthLan
 * @date 2018/7/30
 * @url https://noahlan.com
 */
@Configuration
@EnableWebSocketMessageBroker
@ConditionalOnProperty(prefix = "ws", name = ["enabled"], havingValue = "true", matchIfMissing = true)
//@EnableConfigurationProperties(WebSocketProperties::class)
class WebSocketConfig : AbstractWebSocketMessageBrokerConfigurer() {

    //    @Autowired
    //    private lateinit var webSocketProperties: WebSocketProperties

    override fun configureMessageBroker(registry: MessageBrokerRegistry) {
        /**
         * 客户端需订阅如下地址的消息
         * 服务端通过 @SendTo 或者使用SimpMessageTemplate来发送消息
         */
        registry.enableSimpleBroker("/topic", "/user")
        /**
         * 客户端需用如下地址作为前缀发送消息,经由Broker转发
         */
        registry.setApplicationDestinationPrefixes("/app", "/web")
    }

    override fun registerStompEndpoints(registry: StompEndpointRegistry) {
        /**
         * 以 /ws 作为 Stomp 端点,对外暴露
         */
        registry.addEndpoint("/ws").setAllowedOrigins("*")
    }
}