package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.dto.RequestDto
import com.gxzc.zen.common.dto.ResponseDto
import com.gxzc.zen.logging.annotation.LogAnnotation
import io.swagger.annotations.ApiOperation
import org.apache.shiro.SecurityUtils
import org.slf4j.LoggerFactory
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.servlet.http.Cookie

/**
 * 身份验证相关控制器
 * @author NorthLan
 * @date 2018/2/10
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("auth")
class AuthController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(AuthController::class.java)
    }

    @ApiOperation("设置cookie")
    @PostMapping("/setcookie")
    @LogAnnotation(ignore = true)
    fun token(@RequestBody cookies: List<RequestDto>): ResponseEntity<*> {
        cookies.forEach {
            getResponse().addCookie(Cookie(it["name"]?.toString(), it["value"]?.toString()).apply {
                path = "/"
//                secure = it["secure"] as Boolean
//                isHttpOnly = it["httpOnly"] as Boolean
            })
        }
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation(value = "登出")
    @DeleteMapping("/logout")
    @LogAnnotation(ignore = true)
    fun logout(): ResponseEntity<*> {
        SecurityUtils.getSubject().logout()
//        SSOHelper.clearLogin(getRequest(), getResponse())
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation(value = "验证登录状态")
    @GetMapping("/check")
    @LogAnnotation(ignore = true)
    fun check(): ResponseEntity<*> {
        val subject = SecurityUtils.getSubject()
        return if (subject != null && subject.isAuthenticated) {
            ResponseEntity.ok(ResponseDto())
        } else {
            ResponseEntity.ok(ResponseDto().apply {
                code = 401
            })
        }
    }
}